==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OsobaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class OsobaKontoBankoweKey extends GenericDPSObject {
    /**
     * OSOBA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kontoId;

    /**
     * OSOBA_KONTO_BANKOWE.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKontoId() {
        return kontoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OSOBA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return OSOBA_KONTO_BANKOWE.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_KONTO_BANKOWE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaKontoBankoweKey other = (OsobaKontoBankoweKey) that;
        return (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kontoId=").append(kontoId);
        sb.append(", osobaId=").append(osobaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OsobaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class OsobaKontoBankoweKey extends GenericDPSObject {
    /**
     * OSOBA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kontoId;

    /**
     * OSOBA_KONTO_BANKOWE.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKontoId() {
        return kontoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OSOBA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return OSOBA_KONTO_BANKOWE.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_KONTO_BANKOWE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaKontoBankoweKey other = (OsobaKontoBankoweKey) that;
        return (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kontoId=").append(kontoId);
        sb.append(", osobaId=").append(osobaId);
        sb.append("]");
        return sb.toString();
    }
}
